@@ -1,7 +1,7 @@
 package Perinci::AccessUtil;
 
-our $DATE = '2014-10-24'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-06'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +30,7 @@ sub insert_riap_stuffs_to_res {
             }
             last unless defined($res->[2]) && !ref($res->[2]) &&
                 $res->[2] =~ /[^\x20-\x7f]/;
-            $res->[2] = encode_base64($res->[2]);
+            $res->[2] = encode_base64($res->[2], "");
             $res->[3]{'riap.result_encoding'} = 'base64';
         }
     }
@@ -99,7 +99,7 @@ Perinci::AccessUtil - Utility module for Riap client/server
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::AccessUtil (from Perl distribution Perinci-AccessUtil), released on 2014-10-24.
+This document describes version 0.06 of Perinci::AccessUtil (from Perl distribution Perinci-AccessUtil), released on 2015-09-06.
 
 =head1 SYNOPSIS
 
@@ -178,7 +178,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
